# coding: utf-8

"""
    Trackside Software TeamDB API v2.0

    This API enables you to access TeamDB data  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@trackside.fr
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from teamdbapi.api_client import ApiClient


class ModelFieldApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def model_field_create_model_field(self, new_model_field, **kwargs):  # noqa: E501
        """Create a new model field  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.model_field_create_model_field(new_model_field, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ModelField new_model_field: The model field to create. (required)
        :return: ModelField
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.model_field_create_model_field_with_http_info(new_model_field, **kwargs)  # noqa: E501
        else:
            (data) = self.model_field_create_model_field_with_http_info(new_model_field, **kwargs)  # noqa: E501
            return data

    def model_field_create_model_field_with_http_info(self, new_model_field, **kwargs):  # noqa: E501
        """Create a new model field  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.model_field_create_model_field_with_http_info(new_model_field, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ModelField new_model_field: The model field to create. (required)
        :return: ModelField
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['new_model_field']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method model_field_create_model_field" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'new_model_field' is set
        if self.api_client.client_side_validation and ('new_model_field' not in params or
                                                       params['new_model_field'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `new_model_field` when calling `model_field_create_model_field`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'new_model_field' in params:
            body_params = params['new_model_field']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/modelfield', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ModelField',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def model_field_delete_model_field(self, model_field_id, **kwargs):  # noqa: E501
        """Delete an existing model field  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.model_field_delete_model_field(model_field_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_field_id: The unique model field id for which you want to delete the model field (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.model_field_delete_model_field_with_http_info(model_field_id, **kwargs)  # noqa: E501
        else:
            (data) = self.model_field_delete_model_field_with_http_info(model_field_id, **kwargs)  # noqa: E501
            return data

    def model_field_delete_model_field_with_http_info(self, model_field_id, **kwargs):  # noqa: E501
        """Delete an existing model field  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.model_field_delete_model_field_with_http_info(model_field_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_field_id: The unique model field id for which you want to delete the model field (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['model_field_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method model_field_delete_model_field" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'model_field_id' is set
        if self.api_client.client_side_validation and ('model_field_id' not in params or
                                                       params['model_field_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `model_field_id` when calling `model_field_delete_model_field`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'model_field_id' in params:
            path_params['modelFieldId'] = params['model_field_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/modelfield/{modelFieldId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def model_field_get_model_field_authorizations(self, model_field_id, **kwargs):  # noqa: E501
        """Get authorizations for a model field via its unique id.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.model_field_get_model_field_authorizations(model_field_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_field_id: The unique model field id for which you want to get the model field (required)
        :return: list[ModelFieldAuthorization]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.model_field_get_model_field_authorizations_with_http_info(model_field_id, **kwargs)  # noqa: E501
        else:
            (data) = self.model_field_get_model_field_authorizations_with_http_info(model_field_id, **kwargs)  # noqa: E501
            return data

    def model_field_get_model_field_authorizations_with_http_info(self, model_field_id, **kwargs):  # noqa: E501
        """Get authorizations for a model field via its unique id.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.model_field_get_model_field_authorizations_with_http_info(model_field_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_field_id: The unique model field id for which you want to get the model field (required)
        :return: list[ModelFieldAuthorization]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['model_field_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method model_field_get_model_field_authorizations" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'model_field_id' is set
        if self.api_client.client_side_validation and ('model_field_id' not in params or
                                                       params['model_field_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `model_field_id` when calling `model_field_get_model_field_authorizations`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'model_field_id' in params:
            path_params['modelFieldId'] = params['model_field_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/modelfield/{modelFieldId}/auths', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[ModelFieldAuthorization]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def model_field_get_model_field(self, model_field_id, **kwargs):  # noqa: E501
        """Get a model field via a unique id.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.model_field_get_model_field(model_field_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_field_id: The unique model field id for which you want to get the model field (required)
        :return: ModelField
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.model_field_get_model_field_with_http_info(model_field_id, **kwargs)  # noqa: E501
        else:
            (data) = self.model_field_get_model_field_with_http_info(model_field_id, **kwargs)  # noqa: E501
            return data

    def model_field_get_model_field_with_http_info(self, model_field_id, **kwargs):  # noqa: E501
        """Get a model field via a unique id.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.model_field_get_model_field_with_http_info(model_field_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_field_id: The unique model field id for which you want to get the model field (required)
        :return: ModelField
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['model_field_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method model_field_get_model_field" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'model_field_id' is set
        if self.api_client.client_side_validation and ('model_field_id' not in params or
                                                       params['model_field_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `model_field_id` when calling `model_field_get_model_field`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'model_field_id' in params:
            path_params['modelFieldId'] = params['model_field_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/modelfield/{modelFieldId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ModelField',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def model_field_get_model_fields(self, field_type, **kwargs):  # noqa: E501
        """Get the list of all model fields.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.model_field_get_model_fields(field_type, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str field_type: The field type for which to return the model fields. (required)
        :return: list[CoupleGuidText]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.model_field_get_model_fields_with_http_info(field_type, **kwargs)  # noqa: E501
        else:
            (data) = self.model_field_get_model_fields_with_http_info(field_type, **kwargs)  # noqa: E501
            return data

    def model_field_get_model_fields_with_http_info(self, field_type, **kwargs):  # noqa: E501
        """Get the list of all model fields.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.model_field_get_model_fields_with_http_info(field_type, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str field_type: The field type for which to return the model fields. (required)
        :return: list[CoupleGuidText]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['field_type']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method model_field_get_model_fields" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'field_type' is set
        if self.api_client.client_side_validation and ('field_type' not in params or
                                                       params['field_type'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `field_type` when calling `model_field_get_model_fields`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'field_type' in params:
            query_params.append(('fieldType', params['field_type']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/modelfields', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[CoupleGuidText]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def model_field_update_model_field(self, model_field_id, updated_model_field, **kwargs):  # noqa: E501
        """Update an existing model field  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.model_field_update_model_field(model_field_id, updated_model_field, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_field_id: The unique model field id for which you want to update the modelfield (required)
        :param ModelField updated_model_field: The model field to update. (required)
        :return: ModelField
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.model_field_update_model_field_with_http_info(model_field_id, updated_model_field, **kwargs)  # noqa: E501
        else:
            (data) = self.model_field_update_model_field_with_http_info(model_field_id, updated_model_field, **kwargs)  # noqa: E501
            return data

    def model_field_update_model_field_with_http_info(self, model_field_id, updated_model_field, **kwargs):  # noqa: E501
        """Update an existing model field  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.model_field_update_model_field_with_http_info(model_field_id, updated_model_field, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_field_id: The unique model field id for which you want to update the modelfield (required)
        :param ModelField updated_model_field: The model field to update. (required)
        :return: ModelField
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['model_field_id', 'updated_model_field']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method model_field_update_model_field" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'model_field_id' is set
        if self.api_client.client_side_validation and ('model_field_id' not in params or
                                                       params['model_field_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `model_field_id` when calling `model_field_update_model_field`")  # noqa: E501
        # verify the required parameter 'updated_model_field' is set
        if self.api_client.client_side_validation and ('updated_model_field' not in params or
                                                       params['updated_model_field'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `updated_model_field` when calling `model_field_update_model_field`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'model_field_id' in params:
            path_params['modelFieldId'] = params['model_field_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'updated_model_field' in params:
            body_params = params['updated_model_field']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/modelfield/{modelFieldId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ModelField',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def model_field_update_model_field_authorization(self, model_field_id, **kwargs):  # noqa: E501
        """Set/Update a model field authorization  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.model_field_update_model_field_authorization(model_field_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_field_id: The unique model field id for which you want to set/update the authorizations (required)
        :param ModelFieldAuthorization authorization: The authorization for the model field.
        :return: ModelFieldAuthorization
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.model_field_update_model_field_authorization_with_http_info(model_field_id, **kwargs)  # noqa: E501
        else:
            (data) = self.model_field_update_model_field_authorization_with_http_info(model_field_id, **kwargs)  # noqa: E501
            return data

    def model_field_update_model_field_authorization_with_http_info(self, model_field_id, **kwargs):  # noqa: E501
        """Set/Update a model field authorization  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.model_field_update_model_field_authorization_with_http_info(model_field_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_field_id: The unique model field id for which you want to set/update the authorizations (required)
        :param ModelFieldAuthorization authorization: The authorization for the model field.
        :return: ModelFieldAuthorization
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['model_field_id', 'authorization']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method model_field_update_model_field_authorization" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'model_field_id' is set
        if self.api_client.client_side_validation and ('model_field_id' not in params or
                                                       params['model_field_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `model_field_id` when calling `model_field_update_model_field_authorization`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'model_field_id' in params:
            path_params['modelFieldId'] = params['model_field_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'authorization' in params:
            body_params = params['authorization']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/modelfield/{modelFieldId}/auth', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ModelFieldAuthorization',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Trackside Software TeamDB API v2.0

    This API enables you to access TeamDB data  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@trackside.fr
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from teamdbapi.configuration import Configuration


class ImportParametersResults(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'before_import_warning': 'str',
        'import_report_result': 'str',
        'assembly_created': 'Assembly'
    }

    attribute_map = {
        'before_import_warning': 'BeforeImportWarning',
        'import_report_result': 'ImportReportResult',
        'assembly_created': 'AssemblyCreated'
    }

    def __init__(self, before_import_warning=None, import_report_result=None, assembly_created=None, _configuration=None):  # noqa: E501
        """ImportParametersResults - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._before_import_warning = None
        self._import_report_result = None
        self._assembly_created = None
        self.discriminator = None

        if before_import_warning is not None:
            self.before_import_warning = before_import_warning
        if import_report_result is not None:
            self.import_report_result = import_report_result
        if assembly_created is not None:
            self.assembly_created = assembly_created

    @property
    def before_import_warning(self):
        """Gets the before_import_warning of this ImportParametersResults.  # noqa: E501

        Warning before import  # noqa: E501

        :return: The before_import_warning of this ImportParametersResults.  # noqa: E501
        :rtype: str
        """
        return self._before_import_warning

    @before_import_warning.setter
    def before_import_warning(self, before_import_warning):
        """Sets the before_import_warning of this ImportParametersResults.

        Warning before import  # noqa: E501

        :param before_import_warning: The before_import_warning of this ImportParametersResults.  # noqa: E501
        :type: str
        """

        self._before_import_warning = before_import_warning

    @property
    def import_report_result(self):
        """Gets the import_report_result of this ImportParametersResults.  # noqa: E501

        The import report result  # noqa: E501

        :return: The import_report_result of this ImportParametersResults.  # noqa: E501
        :rtype: str
        """
        return self._import_report_result

    @import_report_result.setter
    def import_report_result(self, import_report_result):
        """Sets the import_report_result of this ImportParametersResults.

        The import report result  # noqa: E501

        :param import_report_result: The import_report_result of this ImportParametersResults.  # noqa: E501
        :type: str
        """

        self._import_report_result = import_report_result

    @property
    def assembly_created(self):
        """Gets the assembly_created of this ImportParametersResults.  # noqa: E501


        :return: The assembly_created of this ImportParametersResults.  # noqa: E501
        :rtype: Assembly
        """
        return self._assembly_created

    @assembly_created.setter
    def assembly_created(self, assembly_created):
        """Sets the assembly_created of this ImportParametersResults.


        :param assembly_created: The assembly_created of this ImportParametersResults.  # noqa: E501
        :type: Assembly
        """

        self._assembly_created = assembly_created

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ImportParametersResults, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ImportParametersResults):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ImportParametersResults):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Trackside Software TeamDB API v2.0

    This API enables you to access TeamDB data  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@trackside.fr
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from teamdbapi.api_client import ApiClient


class RevisionEditorSelectorApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def revision_editor_selector_clear_revision_selector_filters(self, event_id, target_id, **kwargs):  # noqa: E501
        """[Command] Clear a tags list for an event and a target in order to filter the revision selector fields displayed on the drop down  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.revision_editor_selector_clear_revision_selector_filters(event_id, target_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str event_id: The event unique id for which you want to clear the tags list (required)
        :param str target_id: The target unique id for which you want to clear the tags list (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.revision_editor_selector_clear_revision_selector_filters_with_http_info(event_id, target_id, **kwargs)  # noqa: E501
        else:
            (data) = self.revision_editor_selector_clear_revision_selector_filters_with_http_info(event_id, target_id, **kwargs)  # noqa: E501
            return data

    def revision_editor_selector_clear_revision_selector_filters_with_http_info(self, event_id, target_id, **kwargs):  # noqa: E501
        """[Command] Clear a tags list for an event and a target in order to filter the revision selector fields displayed on the drop down  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.revision_editor_selector_clear_revision_selector_filters_with_http_info(event_id, target_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str event_id: The event unique id for which you want to clear the tags list (required)
        :param str target_id: The target unique id for which you want to clear the tags list (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['event_id', 'target_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method revision_editor_selector_clear_revision_selector_filters" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'event_id' is set
        if self.api_client.client_side_validation and ('event_id' not in params or
                                                       params['event_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `event_id` when calling `revision_editor_selector_clear_revision_selector_filters`")  # noqa: E501
        # verify the required parameter 'target_id' is set
        if self.api_client.client_side_validation and ('target_id' not in params or
                                                       params['target_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `target_id` when calling `revision_editor_selector_clear_revision_selector_filters`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'event_id' in params:
            path_params['eventId'] = params['event_id']  # noqa: E501

        query_params = []
        if 'target_id' in params:
            query_params.append(('targetId', params['target_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/event/{eventId}/clearrevisionselectorfilters', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def revision_editor_selector_get_revision_editor_value(self, model_field_id, parent_item_id, **kwargs):  # noqa: E501
        """Get the value of a RevisionEditor field depending on a model field id and a parent item Id (that corresponds to the run Id).  Important notice : RevisionEditor fields work only with Single value Parameters. 2D and 3D Parameters are not supported.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.revision_editor_selector_get_revision_editor_value(model_field_id, parent_item_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_field_id: The model field id for which you want to get the revision editor value (required)
        :param str parent_item_id: The parent item id (run id) for which you want to get the revision editor value (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.revision_editor_selector_get_revision_editor_value_with_http_info(model_field_id, parent_item_id, **kwargs)  # noqa: E501
        else:
            (data) = self.revision_editor_selector_get_revision_editor_value_with_http_info(model_field_id, parent_item_id, **kwargs)  # noqa: E501
            return data

    def revision_editor_selector_get_revision_editor_value_with_http_info(self, model_field_id, parent_item_id, **kwargs):  # noqa: E501
        """Get the value of a RevisionEditor field depending on a model field id and a parent item Id (that corresponds to the run Id).  Important notice : RevisionEditor fields work only with Single value Parameters. 2D and 3D Parameters are not supported.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.revision_editor_selector_get_revision_editor_value_with_http_info(model_field_id, parent_item_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_field_id: The model field id for which you want to get the revision editor value (required)
        :param str parent_item_id: The parent item id (run id) for which you want to get the revision editor value (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['model_field_id', 'parent_item_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method revision_editor_selector_get_revision_editor_value" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'model_field_id' is set
        if self.api_client.client_side_validation and ('model_field_id' not in params or
                                                       params['model_field_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `model_field_id` when calling `revision_editor_selector_get_revision_editor_value`")  # noqa: E501
        # verify the required parameter 'parent_item_id' is set
        if self.api_client.client_side_validation and ('parent_item_id' not in params or
                                                       params['parent_item_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `parent_item_id` when calling `revision_editor_selector_get_revision_editor_value`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'model_field_id' in params:
            path_params['modelFieldId'] = params['model_field_id']  # noqa: E501

        query_params = []
        if 'parent_item_id' in params:
            query_params.append(('parentItemId', params['parent_item_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/modelfield/{modelFieldId}/revisioneditorvalue', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def revision_editor_selector_get_revision_selector_filters(self, event_id, target_id, **kwargs):  # noqa: E501
        """Get the tags list defined for an event and a target in order to filter the revision selector fields displayed on the drop down  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.revision_editor_selector_get_revision_selector_filters(event_id, target_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str event_id: The event unique id for which you want to get the tags list (required)
        :param str target_id: The target unique id for which you want to get the tags list (required)
        :return: list[str]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.revision_editor_selector_get_revision_selector_filters_with_http_info(event_id, target_id, **kwargs)  # noqa: E501
        else:
            (data) = self.revision_editor_selector_get_revision_selector_filters_with_http_info(event_id, target_id, **kwargs)  # noqa: E501
            return data

    def revision_editor_selector_get_revision_selector_filters_with_http_info(self, event_id, target_id, **kwargs):  # noqa: E501
        """Get the tags list defined for an event and a target in order to filter the revision selector fields displayed on the drop down  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.revision_editor_selector_get_revision_selector_filters_with_http_info(event_id, target_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str event_id: The event unique id for which you want to get the tags list (required)
        :param str target_id: The target unique id for which you want to get the tags list (required)
        :return: list[str]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['event_id', 'target_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method revision_editor_selector_get_revision_selector_filters" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'event_id' is set
        if self.api_client.client_side_validation and ('event_id' not in params or
                                                       params['event_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `event_id` when calling `revision_editor_selector_get_revision_selector_filters`")  # noqa: E501
        # verify the required parameter 'target_id' is set
        if self.api_client.client_side_validation and ('target_id' not in params or
                                                       params['target_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `target_id` when calling `revision_editor_selector_get_revision_selector_filters`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'event_id' in params:
            path_params['eventId'] = params['event_id']  # noqa: E501

        query_params = []
        if 'target_id' in params:
            query_params.append(('targetId', params['target_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/event/{eventId}/revisionselectorfilters', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[str]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def revision_editor_selector_get_revision_selector_list_of_values(self, model_field_id, parent_item_id, **kwargs):  # noqa: E501
        """Get the list of all the available values for a RevisionSelector field depending on a model field id and a parent item Id (that corresponds to the run Id).  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.revision_editor_selector_get_revision_selector_list_of_values(model_field_id, parent_item_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_field_id: The model field id for which you want to get the revision selector value (required)
        :param str parent_item_id: The parent item id (run id) for which you want to get the revision selector value (required)
        :return: list[str]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.revision_editor_selector_get_revision_selector_list_of_values_with_http_info(model_field_id, parent_item_id, **kwargs)  # noqa: E501
        else:
            (data) = self.revision_editor_selector_get_revision_selector_list_of_values_with_http_info(model_field_id, parent_item_id, **kwargs)  # noqa: E501
            return data

    def revision_editor_selector_get_revision_selector_list_of_values_with_http_info(self, model_field_id, parent_item_id, **kwargs):  # noqa: E501
        """Get the list of all the available values for a RevisionSelector field depending on a model field id and a parent item Id (that corresponds to the run Id).  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.revision_editor_selector_get_revision_selector_list_of_values_with_http_info(model_field_id, parent_item_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_field_id: The model field id for which you want to get the revision selector value (required)
        :param str parent_item_id: The parent item id (run id) for which you want to get the revision selector value (required)
        :return: list[str]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['model_field_id', 'parent_item_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method revision_editor_selector_get_revision_selector_list_of_values" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'model_field_id' is set
        if self.api_client.client_side_validation and ('model_field_id' not in params or
                                                       params['model_field_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `model_field_id` when calling `revision_editor_selector_get_revision_selector_list_of_values`")  # noqa: E501
        # verify the required parameter 'parent_item_id' is set
        if self.api_client.client_side_validation and ('parent_item_id' not in params or
                                                       params['parent_item_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `parent_item_id` when calling `revision_editor_selector_get_revision_selector_list_of_values`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'model_field_id' in params:
            path_params['modelFieldId'] = params['model_field_id']  # noqa: E501

        query_params = []
        if 'parent_item_id' in params:
            query_params.append(('parentItemId', params['parent_item_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/modelfield/{modelFieldId}/revisionselectorvalues', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[str]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def revision_editor_selector_get_revision_selector_value(self, model_field_id, parent_item_id, **kwargs):  # noqa: E501
        """Get the value of a RevisionSelector field depending on a model field id and a parent item Id (that corresponds to the run Id).  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.revision_editor_selector_get_revision_selector_value(model_field_id, parent_item_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_field_id: The model field id for which you want to get the revision selector value (required)
        :param str parent_item_id: The parent item id (run id) for which you want to get the revision selector value (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.revision_editor_selector_get_revision_selector_value_with_http_info(model_field_id, parent_item_id, **kwargs)  # noqa: E501
        else:
            (data) = self.revision_editor_selector_get_revision_selector_value_with_http_info(model_field_id, parent_item_id, **kwargs)  # noqa: E501
            return data

    def revision_editor_selector_get_revision_selector_value_with_http_info(self, model_field_id, parent_item_id, **kwargs):  # noqa: E501
        """Get the value of a RevisionSelector field depending on a model field id and a parent item Id (that corresponds to the run Id).  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.revision_editor_selector_get_revision_selector_value_with_http_info(model_field_id, parent_item_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_field_id: The model field id for which you want to get the revision selector value (required)
        :param str parent_item_id: The parent item id (run id) for which you want to get the revision selector value (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['model_field_id', 'parent_item_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method revision_editor_selector_get_revision_selector_value" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'model_field_id' is set
        if self.api_client.client_side_validation and ('model_field_id' not in params or
                                                       params['model_field_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `model_field_id` when calling `revision_editor_selector_get_revision_selector_value`")  # noqa: E501
        # verify the required parameter 'parent_item_id' is set
        if self.api_client.client_side_validation and ('parent_item_id' not in params or
                                                       params['parent_item_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `parent_item_id` when calling `revision_editor_selector_get_revision_selector_value`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'model_field_id' in params:
            path_params['modelFieldId'] = params['model_field_id']  # noqa: E501

        query_params = []
        if 'parent_item_id' in params:
            query_params.append(('parentItemId', params['parent_item_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/modelfield/{modelFieldId}/revisionselectorvalue', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def revision_editor_selector_remove_revision_selector_filters(self, event_id, target_id, tags, **kwargs):  # noqa: E501
        """[Command] Remove a tags list for an event and a target in order to filter the revision selector fields displayed on the drop down  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.revision_editor_selector_remove_revision_selector_filters(event_id, target_id, tags, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str event_id: The event unique id for which you want to remove the tags list (required)
        :param str target_id: The target unique id for which you want to remove the tags list (required)
        :param list[str] tags: The tags used to filter the revision selector fields you want to remove (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.revision_editor_selector_remove_revision_selector_filters_with_http_info(event_id, target_id, tags, **kwargs)  # noqa: E501
        else:
            (data) = self.revision_editor_selector_remove_revision_selector_filters_with_http_info(event_id, target_id, tags, **kwargs)  # noqa: E501
            return data

    def revision_editor_selector_remove_revision_selector_filters_with_http_info(self, event_id, target_id, tags, **kwargs):  # noqa: E501
        """[Command] Remove a tags list for an event and a target in order to filter the revision selector fields displayed on the drop down  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.revision_editor_selector_remove_revision_selector_filters_with_http_info(event_id, target_id, tags, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str event_id: The event unique id for which you want to remove the tags list (required)
        :param str target_id: The target unique id for which you want to remove the tags list (required)
        :param list[str] tags: The tags used to filter the revision selector fields you want to remove (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['event_id', 'target_id', 'tags']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method revision_editor_selector_remove_revision_selector_filters" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'event_id' is set
        if self.api_client.client_side_validation and ('event_id' not in params or
                                                       params['event_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `event_id` when calling `revision_editor_selector_remove_revision_selector_filters`")  # noqa: E501
        # verify the required parameter 'target_id' is set
        if self.api_client.client_side_validation and ('target_id' not in params or
                                                       params['target_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `target_id` when calling `revision_editor_selector_remove_revision_selector_filters`")  # noqa: E501
        # verify the required parameter 'tags' is set
        if self.api_client.client_side_validation and ('tags' not in params or
                                                       params['tags'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `tags` when calling `revision_editor_selector_remove_revision_selector_filters`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'event_id' in params:
            path_params['eventId'] = params['event_id']  # noqa: E501

        query_params = []
        if 'target_id' in params:
            query_params.append(('targetId', params['target_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'tags' in params:
            body_params = params['tags']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/event/{eventId}/removerevisionselectorfilters', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def revision_editor_selector_set_revision_editor_value(self, model_field_id, parent_item_id, value, **kwargs):  # noqa: E501
        """[Command] Set the value of a RevisionEditor field depending on a model field id and a parent item Id (that corresponds to the run Id).  Important notice : RevisionEditor fields work only with Single value Parameters. 2D and 3D Parameters are not supported.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.revision_editor_selector_set_revision_editor_value(model_field_id, parent_item_id, value, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_field_id: The model field id for which you want to get the revision editor value (required)
        :param str parent_item_id: The parent item id (run id) for which you want to get the revision editor value (required)
        :param object value: The new value (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.revision_editor_selector_set_revision_editor_value_with_http_info(model_field_id, parent_item_id, value, **kwargs)  # noqa: E501
        else:
            (data) = self.revision_editor_selector_set_revision_editor_value_with_http_info(model_field_id, parent_item_id, value, **kwargs)  # noqa: E501
            return data

    def revision_editor_selector_set_revision_editor_value_with_http_info(self, model_field_id, parent_item_id, value, **kwargs):  # noqa: E501
        """[Command] Set the value of a RevisionEditor field depending on a model field id and a parent item Id (that corresponds to the run Id).  Important notice : RevisionEditor fields work only with Single value Parameters. 2D and 3D Parameters are not supported.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.revision_editor_selector_set_revision_editor_value_with_http_info(model_field_id, parent_item_id, value, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_field_id: The model field id for which you want to get the revision editor value (required)
        :param str parent_item_id: The parent item id (run id) for which you want to get the revision editor value (required)
        :param object value: The new value (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['model_field_id', 'parent_item_id', 'value']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method revision_editor_selector_set_revision_editor_value" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'model_field_id' is set
        if self.api_client.client_side_validation and ('model_field_id' not in params or
                                                       params['model_field_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `model_field_id` when calling `revision_editor_selector_set_revision_editor_value`")  # noqa: E501
        # verify the required parameter 'parent_item_id' is set
        if self.api_client.client_side_validation and ('parent_item_id' not in params or
                                                       params['parent_item_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `parent_item_id` when calling `revision_editor_selector_set_revision_editor_value`")  # noqa: E501
        # verify the required parameter 'value' is set
        if self.api_client.client_side_validation and ('value' not in params or
                                                       params['value'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `value` when calling `revision_editor_selector_set_revision_editor_value`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'model_field_id' in params:
            path_params['modelFieldId'] = params['model_field_id']  # noqa: E501

        query_params = []
        if 'parent_item_id' in params:
            query_params.append(('parentItemId', params['parent_item_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'value' in params:
            body_params = params['value']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/modelfield/{modelFieldId}/revisioneditorvalue', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def revision_editor_selector_set_revision_selector_filters(self, event_id, target_id, tags, **kwargs):  # noqa: E501
        """[Command] Set the tags list for an event and a target in order to filter the revision selector fields displayed on the drop down  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.revision_editor_selector_set_revision_selector_filters(event_id, target_id, tags, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str event_id: The event unique id for which you want to add the tags list (required)
        :param str target_id: The target unique id for which you want to add the tags list (required)
        :param list[str] tags: The tags used to filter the revision selector fields you want to add (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.revision_editor_selector_set_revision_selector_filters_with_http_info(event_id, target_id, tags, **kwargs)  # noqa: E501
        else:
            (data) = self.revision_editor_selector_set_revision_selector_filters_with_http_info(event_id, target_id, tags, **kwargs)  # noqa: E501
            return data

    def revision_editor_selector_set_revision_selector_filters_with_http_info(self, event_id, target_id, tags, **kwargs):  # noqa: E501
        """[Command] Set the tags list for an event and a target in order to filter the revision selector fields displayed on the drop down  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.revision_editor_selector_set_revision_selector_filters_with_http_info(event_id, target_id, tags, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str event_id: The event unique id for which you want to add the tags list (required)
        :param str target_id: The target unique id for which you want to add the tags list (required)
        :param list[str] tags: The tags used to filter the revision selector fields you want to add (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['event_id', 'target_id', 'tags']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method revision_editor_selector_set_revision_selector_filters" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'event_id' is set
        if self.api_client.client_side_validation and ('event_id' not in params or
                                                       params['event_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `event_id` when calling `revision_editor_selector_set_revision_selector_filters`")  # noqa: E501
        # verify the required parameter 'target_id' is set
        if self.api_client.client_side_validation and ('target_id' not in params or
                                                       params['target_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `target_id` when calling `revision_editor_selector_set_revision_selector_filters`")  # noqa: E501
        # verify the required parameter 'tags' is set
        if self.api_client.client_side_validation and ('tags' not in params or
                                                       params['tags'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `tags` when calling `revision_editor_selector_set_revision_selector_filters`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'event_id' in params:
            path_params['eventId'] = params['event_id']  # noqa: E501

        query_params = []
        if 'target_id' in params:
            query_params.append(('targetId', params['target_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'tags' in params:
            body_params = params['tags']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/event/{eventId}/revisionselectorfilters', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def revision_editor_selector_set_revision_selector_value(self, model_field_id, parent_item_id, value, **kwargs):  # noqa: E501
        """[Command] Set the value of a RevisionSelector field depending on a model field id and a parent item Id (that corresponds to the run Id).  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.revision_editor_selector_set_revision_selector_value(model_field_id, parent_item_id, value, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_field_id: The model field id for which you want to get the revision selector value (required)
        :param str parent_item_id: The parent item id (run id) for which you want to get the revision selector value (required)
        :param str value: The revision name value to apply. This value must match with a value available in the GetRevisionSelectorListOfValues function (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.revision_editor_selector_set_revision_selector_value_with_http_info(model_field_id, parent_item_id, value, **kwargs)  # noqa: E501
        else:
            (data) = self.revision_editor_selector_set_revision_selector_value_with_http_info(model_field_id, parent_item_id, value, **kwargs)  # noqa: E501
            return data

    def revision_editor_selector_set_revision_selector_value_with_http_info(self, model_field_id, parent_item_id, value, **kwargs):  # noqa: E501
        """[Command] Set the value of a RevisionSelector field depending on a model field id and a parent item Id (that corresponds to the run Id).  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.revision_editor_selector_set_revision_selector_value_with_http_info(model_field_id, parent_item_id, value, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str model_field_id: The model field id for which you want to get the revision selector value (required)
        :param str parent_item_id: The parent item id (run id) for which you want to get the revision selector value (required)
        :param str value: The revision name value to apply. This value must match with a value available in the GetRevisionSelectorListOfValues function (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['model_field_id', 'parent_item_id', 'value']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method revision_editor_selector_set_revision_selector_value" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'model_field_id' is set
        if self.api_client.client_side_validation and ('model_field_id' not in params or
                                                       params['model_field_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `model_field_id` when calling `revision_editor_selector_set_revision_selector_value`")  # noqa: E501
        # verify the required parameter 'parent_item_id' is set
        if self.api_client.client_side_validation and ('parent_item_id' not in params or
                                                       params['parent_item_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `parent_item_id` when calling `revision_editor_selector_set_revision_selector_value`")  # noqa: E501
        # verify the required parameter 'value' is set
        if self.api_client.client_side_validation and ('value' not in params or
                                                       params['value'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `value` when calling `revision_editor_selector_set_revision_selector_value`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'model_field_id' in params:
            path_params['modelFieldId'] = params['model_field_id']  # noqa: E501

        query_params = []
        if 'parent_item_id' in params:
            query_params.append(('parentItemId', params['parent_item_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'value' in params:
            body_params = params['value']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/modelfield/{modelFieldId}/revisionselectorvalue', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Trackside Software TeamDB API v2.0

    This API enables you to access TeamDB data  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@trackside.fr
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from teamdbapi.api_client import ApiClient


class RevisionApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def revision_create_revision(self, version_id, revision, **kwargs):  # noqa: E501
        """Create a revision. You have to specify a version id to which the revision is created.  This is mandatory because the system needs to ensure that the revision data are consistent with the version definition.  # noqa: E501

        Set the Revision.Id to empty (00000000-0000-0000-0000-000000000000), it will be generated by the server.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.revision_create_revision(version_id, revision, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str version_id: The version id to which the revision was created (required)
        :param Revision revision: The revision you want to create (required)
        :return: Revision
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.revision_create_revision_with_http_info(version_id, revision, **kwargs)  # noqa: E501
        else:
            (data) = self.revision_create_revision_with_http_info(version_id, revision, **kwargs)  # noqa: E501
            return data

    def revision_create_revision_with_http_info(self, version_id, revision, **kwargs):  # noqa: E501
        """Create a revision. You have to specify a version id to which the revision is created.  This is mandatory because the system needs to ensure that the revision data are consistent with the version definition.  # noqa: E501

        Set the Revision.Id to empty (00000000-0000-0000-0000-000000000000), it will be generated by the server.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.revision_create_revision_with_http_info(version_id, revision, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str version_id: The version id to which the revision was created (required)
        :param Revision revision: The revision you want to create (required)
        :return: Revision
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['version_id', 'revision']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method revision_create_revision" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'version_id' is set
        if self.api_client.client_side_validation and ('version_id' not in params or
                                                       params['version_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `version_id` when calling `revision_create_revision`")  # noqa: E501
        # verify the required parameter 'revision' is set
        if self.api_client.client_side_validation and ('revision' not in params or
                                                       params['revision'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `revision` when calling `revision_create_revision`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'version_id' in params:
            path_params['versionId'] = params['version_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'revision' in params:
            body_params = params['revision']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/version/{versionId}/revision', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Revision',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def revision_delete_revision(self, revision_id, **kwargs):  # noqa: E501
        """Remove a revision corresponding to a given id.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.revision_delete_revision(revision_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str revision_id: The revision id you want to remove (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.revision_delete_revision_with_http_info(revision_id, **kwargs)  # noqa: E501
        else:
            (data) = self.revision_delete_revision_with_http_info(revision_id, **kwargs)  # noqa: E501
            return data

    def revision_delete_revision_with_http_info(self, revision_id, **kwargs):  # noqa: E501
        """Remove a revision corresponding to a given id.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.revision_delete_revision_with_http_info(revision_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str revision_id: The revision id you want to remove (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['revision_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method revision_delete_revision" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'revision_id' is set
        if self.api_client.client_side_validation and ('revision_id' not in params or
                                                       params['revision_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `revision_id` when calling `revision_delete_revision`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'revision_id' in params:
            path_params['revisionId'] = params['revision_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/revision/{revisionId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def revision_export_revision(self, revision_id, version_id, output_file_path, **kwargs):  # noqa: E501
        """[Command] Export a revision into a file. You need to specify the version to which you want to export the revision value.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.revision_export_revision(revision_id, version_id, output_file_path, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str revision_id: The revision id to export. (required)
        :param str version_id: The version id to which you want to export the revision value. (required)
        :param str output_file_path: The path to the file to create. You have to provide the file extension for example : MyFile.m (required)
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.revision_export_revision_with_http_info(revision_id, version_id, output_file_path, **kwargs)  # noqa: E501
        else:
            (data) = self.revision_export_revision_with_http_info(revision_id, version_id, output_file_path, **kwargs)  # noqa: E501
            return data

    def revision_export_revision_with_http_info(self, revision_id, version_id, output_file_path, **kwargs):  # noqa: E501
        """[Command] Export a revision into a file. You need to specify the version to which you want to export the revision value.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.revision_export_revision_with_http_info(revision_id, version_id, output_file_path, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str revision_id: The revision id to export. (required)
        :param str version_id: The version id to which you want to export the revision value. (required)
        :param str output_file_path: The path to the file to create. You have to provide the file extension for example : MyFile.m (required)
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['revision_id', 'version_id', 'output_file_path']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method revision_export_revision" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'revision_id' is set
        if self.api_client.client_side_validation and ('revision_id' not in params or
                                                       params['revision_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `revision_id` when calling `revision_export_revision`")  # noqa: E501
        # verify the required parameter 'version_id' is set
        if self.api_client.client_side_validation and ('version_id' not in params or
                                                       params['version_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `version_id` when calling `revision_export_revision`")  # noqa: E501
        # verify the required parameter 'output_file_path' is set
        if self.api_client.client_side_validation and ('output_file_path' not in params or
                                                       params['output_file_path'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `output_file_path` when calling `revision_export_revision`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'revision_id' in params:
            path_params['revisionId'] = params['revision_id']  # noqa: E501

        query_params = []
        if 'version_id' in params:
            query_params.append(('versionId', params['version_id']))  # noqa: E501
        if 'output_file_path' in params:
            query_params.append(('outputFilePath', params['output_file_path']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/revision/{revisionId}/export', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='bool',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def revision_get_revision(self, revision_id, **kwargs):  # noqa: E501
        """Get a revision corresponding to a unique Id.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.revision_get_revision(revision_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str revision_id: The unique revision id to which you want to get the revision (required)
        :return: Revision
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.revision_get_revision_with_http_info(revision_id, **kwargs)  # noqa: E501
        else:
            (data) = self.revision_get_revision_with_http_info(revision_id, **kwargs)  # noqa: E501
            return data

    def revision_get_revision_with_http_info(self, revision_id, **kwargs):  # noqa: E501
        """Get a revision corresponding to a unique Id.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.revision_get_revision_with_http_info(revision_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str revision_id: The unique revision id to which you want to get the revision (required)
        :return: Revision
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['revision_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method revision_get_revision" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'revision_id' is set
        if self.api_client.client_side_validation and ('revision_id' not in params or
                                                       params['revision_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `revision_id` when calling `revision_get_revision`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'revision_id' in params:
            path_params['revisionId'] = params['revision_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/revision/{revisionId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Revision',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def revision_get_revision_by_param_and_assembly(self, assembly_id, parameter_id, **kwargs):  # noqa: E501
        """Get the revision selected in an assembly for a given parameter.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.revision_get_revision_by_param_and_assembly(assembly_id, parameter_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str assembly_id: The assembly id to which you want to get the revision value (required)
        :param str parameter_id: The parameter id to which you want the revisions (required)
        :return: Revision
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.revision_get_revision_by_param_and_assembly_with_http_info(assembly_id, parameter_id, **kwargs)  # noqa: E501
        else:
            (data) = self.revision_get_revision_by_param_and_assembly_with_http_info(assembly_id, parameter_id, **kwargs)  # noqa: E501
            return data

    def revision_get_revision_by_param_and_assembly_with_http_info(self, assembly_id, parameter_id, **kwargs):  # noqa: E501
        """Get the revision selected in an assembly for a given parameter.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.revision_get_revision_by_param_and_assembly_with_http_info(assembly_id, parameter_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str assembly_id: The assembly id to which you want to get the revision value (required)
        :param str parameter_id: The parameter id to which you want the revisions (required)
        :return: Revision
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['assembly_id', 'parameter_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method revision_get_revision_by_param_and_assembly" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'assembly_id' is set
        if self.api_client.client_side_validation and ('assembly_id' not in params or
                                                       params['assembly_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `assembly_id` when calling `revision_get_revision_by_param_and_assembly`")  # noqa: E501
        # verify the required parameter 'parameter_id' is set
        if self.api_client.client_side_validation and ('parameter_id' not in params or
                                                       params['parameter_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `parameter_id` when calling `revision_get_revision_by_param_and_assembly`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'assembly_id' in params:
            path_params['assemblyId'] = params['assembly_id']  # noqa: E501
        if 'parameter_id' in params:
            path_params['parameterId'] = params['parameter_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/assembly/{assemblyId}/parameter/{parameterId}/revision', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Revision',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def revision_get_revisions(self, version_id, **kwargs):  # noqa: E501
        """Get all the revisions for a given version. This will retreive all revisions for all the parameters of a given version.  Only revisions that match the version definition will be returned.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.revision_get_revisions(version_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str version_id: The version id to which you want all the revisions (required)
        :return: list[Revision]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.revision_get_revisions_with_http_info(version_id, **kwargs)  # noqa: E501
        else:
            (data) = self.revision_get_revisions_with_http_info(version_id, **kwargs)  # noqa: E501
            return data

    def revision_get_revisions_with_http_info(self, version_id, **kwargs):  # noqa: E501
        """Get all the revisions for a given version. This will retreive all revisions for all the parameters of a given version.  Only revisions that match the version definition will be returned.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.revision_get_revisions_with_http_info(version_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str version_id: The version id to which you want all the revisions (required)
        :return: list[Revision]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['version_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method revision_get_revisions" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'version_id' is set
        if self.api_client.client_side_validation and ('version_id' not in params or
                                                       params['version_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `version_id` when calling `revision_get_revisions`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'version_id' in params:
            path_params['versionId'] = params['version_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/version/{versionId}/revisions', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Revision]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def revision_get_revisions(self, parameter_id, version_id, **kwargs):  # noqa: E501
        """Get all revisions for a given parameter and version. You need to specify a version in order to  get the revisions that match the version definition (size, format...)  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.revision_get_revisions(parameter_id, version_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str parameter_id: The parameter id to which you want the revisions (required)
        :param str version_id: The version id to which you want to get the revision value (required)
        :return: list[Revision]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.revision_get_revisions_with_http_info(parameter_id, version_id, **kwargs)  # noqa: E501
        else:
            (data) = self.revision_get_revisions_with_http_info(parameter_id, version_id, **kwargs)  # noqa: E501
            return data

    def revision_get_revisions_with_http_info(self, parameter_id, version_id, **kwargs):  # noqa: E501
        """Get all revisions for a given parameter and version. You need to specify a version in order to  get the revisions that match the version definition (size, format...)  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.revision_get_revisions_with_http_info(parameter_id, version_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str parameter_id: The parameter id to which you want the revisions (required)
        :param str version_id: The version id to which you want to get the revision value (required)
        :return: list[Revision]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['parameter_id', 'version_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method revision_get_revisions" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'parameter_id' is set
        if self.api_client.client_side_validation and ('parameter_id' not in params or
                                                       params['parameter_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `parameter_id` when calling `revision_get_revisions`")  # noqa: E501
        # verify the required parameter 'version_id' is set
        if self.api_client.client_side_validation and ('version_id' not in params or
                                                       params['version_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `version_id` when calling `revision_get_revisions`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'parameter_id' in params:
            path_params['parameterId'] = params['parameter_id']  # noqa: E501
        if 'version_id' in params:
            path_params['versionId'] = params['version_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/version/{versionId}/parameter/{parameterId}/revisions', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Revision]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def revision_try_get_revision(self, version_id, revision, **kwargs):  # noqa: E501
        """Check whether the revision with the same data already exists for a given version.  Returns the revision unique ID already existing or empty (00000000-0000-0000-0000-000000000000) if not found.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.revision_try_get_revision(version_id, revision, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str version_id: The version id to which the revision must belong (required)
        :param Revision revision: The revision you want to check. The research is based on the data not the revision id. (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.revision_try_get_revision_with_http_info(version_id, revision, **kwargs)  # noqa: E501
        else:
            (data) = self.revision_try_get_revision_with_http_info(version_id, revision, **kwargs)  # noqa: E501
            return data

    def revision_try_get_revision_with_http_info(self, version_id, revision, **kwargs):  # noqa: E501
        """Check whether the revision with the same data already exists for a given version.  Returns the revision unique ID already existing or empty (00000000-0000-0000-0000-000000000000) if not found.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.revision_try_get_revision_with_http_info(version_id, revision, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str version_id: The version id to which the revision must belong (required)
        :param Revision revision: The revision you want to check. The research is based on the data not the revision id. (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['version_id', 'revision']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method revision_try_get_revision" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'version_id' is set
        if self.api_client.client_side_validation and ('version_id' not in params or
                                                       params['version_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `version_id` when calling `revision_try_get_revision`")  # noqa: E501
        # verify the required parameter 'revision' is set
        if self.api_client.client_side_validation and ('revision' not in params or
                                                       params['revision'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `revision` when calling `revision_try_get_revision`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'version_id' in params:
            path_params['versionId'] = params['version_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'revision' in params:
            body_params = params['revision']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/version/{versionId}/revision/exists', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def revision_update_revision(self, revision_id, version_id, revision, **kwargs):  # noqa: E501
        """Update a revision. You have to specify a version id to which the revision is updated.  This is mandatory because the system needs to ensure that the revision data are consistent with the version definition.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.revision_update_revision(revision_id, version_id, revision, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str revision_id: The revision id corresponding to the revision you want to update (required)
        :param str version_id: The version id to which the revision was created (required)
        :param Revision revision: The revision you want to update (required)
        :param bool allow_update_revision_fields: Allows to update the all the revision description fields except the data from a locked revision.
        :return: Revision
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.revision_update_revision_with_http_info(revision_id, version_id, revision, **kwargs)  # noqa: E501
        else:
            (data) = self.revision_update_revision_with_http_info(revision_id, version_id, revision, **kwargs)  # noqa: E501
            return data

    def revision_update_revision_with_http_info(self, revision_id, version_id, revision, **kwargs):  # noqa: E501
        """Update a revision. You have to specify a version id to which the revision is updated.  This is mandatory because the system needs to ensure that the revision data are consistent with the version definition.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.revision_update_revision_with_http_info(revision_id, version_id, revision, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str revision_id: The revision id corresponding to the revision you want to update (required)
        :param str version_id: The version id to which the revision was created (required)
        :param Revision revision: The revision you want to update (required)
        :param bool allow_update_revision_fields: Allows to update the all the revision description fields except the data from a locked revision.
        :return: Revision
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['revision_id', 'version_id', 'revision', 'allow_update_revision_fields']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method revision_update_revision" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'revision_id' is set
        if self.api_client.client_side_validation and ('revision_id' not in params or
                                                       params['revision_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `revision_id` when calling `revision_update_revision`")  # noqa: E501
        # verify the required parameter 'version_id' is set
        if self.api_client.client_side_validation and ('version_id' not in params or
                                                       params['version_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `version_id` when calling `revision_update_revision`")  # noqa: E501
        # verify the required parameter 'revision' is set
        if self.api_client.client_side_validation and ('revision' not in params or
                                                       params['revision'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `revision` when calling `revision_update_revision`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'revision_id' in params:
            path_params['revisionId'] = params['revision_id']  # noqa: E501
        if 'version_id' in params:
            path_params['versionId'] = params['version_id']  # noqa: E501

        query_params = []
        if 'allow_update_revision_fields' in params:
            query_params.append(('allowUpdateRevisionFields', params['allow_update_revision_fields']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'revision' in params:
            body_params = params['revision']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/version/{versionId}/revision/{revisionId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Revision',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Trackside Software TeamDB API v2.0

    This API enables you to access TeamDB data  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@trackside.fr
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from teamdbapi.api_client import ApiClient


class ReportApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def report_export_report(self, report_name, format, output_file_path, **kwargs):  # noqa: E501
        """Render the report and export it using the given format.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.report_export_report(report_name, format, output_file_path, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str report_name: The report name (required)
        :param str format: The output file format (required)
        :param str output_file_path: The path to the file to create. You have to provide the file extension for example : C://path/MyFile.pdf (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.report_export_report_with_http_info(report_name, format, output_file_path, **kwargs)  # noqa: E501
        else:
            (data) = self.report_export_report_with_http_info(report_name, format, output_file_path, **kwargs)  # noqa: E501
            return data

    def report_export_report_with_http_info(self, report_name, format, output_file_path, **kwargs):  # noqa: E501
        """Render the report and export it using the given format.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.report_export_report_with_http_info(report_name, format, output_file_path, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str report_name: The report name (required)
        :param str format: The output file format (required)
        :param str output_file_path: The path to the file to create. You have to provide the file extension for example : C://path/MyFile.pdf (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['report_name', 'format', 'output_file_path']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method report_export_report" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'report_name' is set
        if self.api_client.client_side_validation and ('report_name' not in params or
                                                       params['report_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `report_name` when calling `report_export_report`")  # noqa: E501
        # verify the required parameter 'format' is set
        if self.api_client.client_side_validation and ('format' not in params or
                                                       params['format'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `format` when calling `report_export_report`")  # noqa: E501
        # verify the required parameter 'output_file_path' is set
        if self.api_client.client_side_validation and ('output_file_path' not in params or
                                                       params['output_file_path'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `output_file_path` when calling `report_export_report`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'report_name' in params:
            query_params.append(('reportName', params['report_name']))  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501
        if 'output_file_path' in params:
            query_params.append(('outputFilePath', params['output_file_path']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/exportreport', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)
